@@ -14,7 +14,7 @@
 
 package controller
 
-import "github.com/open-cluster-management/multicloud-integrations/pkg/controller/gitopscluster"
+import "github.com/stolostron/multicloud-integrations/pkg/controller/gitopscluster"
 
 func init() {
 	// AddToManagerFuncs is a list of functions to create controllers and add them to a manager.
